@@ -26,7 +26,7 @@ use FusionInventory::Agent::Tools::Network;
 use FusionInventory::Agent::Task::NetDiscovery::Dictionary;
 use FusionInventory::Agent::XML::Query;
 
-our $VERSION = '2.0';
+our $VERSION = '2.1';
 
 my @dispatch_table = (
     {
@@ -561,15 +561,18 @@ sub _scanAddressBySNMP {
                 next unless $description eq $entry->{match};
             }
 
-            $description = runFunction(
+            my $newDescription = runFunction(
                 module   => $entry->{module},
                 function => $entry->{function},
                 params   => $snmp,
                 load     => 1
             );
 
+            $description = $newDescription if $newDescription;
+
             last;
         }
+        next unless $description;
 
         $device{DESCRIPTION} = $description;
 
